
:orphan:

Variant Callers
===============

Automatically generated index page for Variant Callers:

.. raw:: html

   <ul>

   </ul>
     <a href="gatk4_germlinevariantcaller.html">
       <p style="margin-bottom: 5px"><b>GATK4 Germline Variant Caller</b> <span style="margin-left: 10px; color: darkgray">GATK4_GermlineVariantCaller</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="gatk4_germlinevariantcaller.html" style="margin-bottom: 10px">
       v<b>4.1.3.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4_somaticvariantcaller.html">
       <p style="margin-bottom: 5px"><b>GATK4 Somatic Variant Caller</b> <span style="margin-left: 10px; color: darkgray">GATK4_SomaticVariantCaller</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="gatk4_somaticvariantcaller.html" style="margin-bottom: 10px">
       v<b>4.1.3.0</b>
     </a></p>
     </a>
     <hr />
         
     <a href="gatk4_somaticvariantcallertumoronlytargeted.html">
       <p style="margin-bottom: 5px"><b>GATK4 Somatic Variant Caller for Tumour Only Samples with Targeted BED</b> <span style="margin-left: 10px; color: darkgray">GATK4_SomaticVariantCallerTumorOnlyTargeted</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="gatk4_somaticvariantcallertumoronlytargeted.html" style="margin-bottom: 10px">
       v<b>0.1.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="strelkagermlinevariantcaller.html">
       <p style="margin-bottom: 5px"><b>Strelka Germline Variant Caller</b> <span style="margin-left: 10px; color: darkgray">strelkaGermlineVariantCaller</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="strelkagermlinevariantcaller.html" style="margin-bottom: 10px">
       v<b>0.1.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="strelkasomaticvariantcaller.html">
       <p style="margin-bottom: 5px"><b>Strelka Somatic Variant Caller</b> <span style="margin-left: 10px; color: darkgray">strelkaSomaticVariantCaller</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="strelkasomaticvariantcaller.html" style="margin-bottom: 10px">
       v<b>0.1.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="vardictgermlinevariantcaller.html">
       <p style="margin-bottom: 5px"><b>Vardict Germline Variant Caller</b> <span style="margin-left: 10px; color: darkgray">vardictGermlineVariantCaller</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="vardictgermlinevariantcaller.html" style="margin-bottom: 10px">
       v<b>0.1.1</b>
     </a></p>
     </a>
     <hr />
         
     <a href="vardictsomaticvariantcaller.html">
       <p style="margin-bottom: 5px"><b>Vardict Somatic Variant Caller</b> <span style="margin-left: 10px; color: darkgray">vardictSomaticVariantCaller</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="vardictsomaticvariantcaller.html" style="margin-bottom: 10px">
       v<b>0.1.0</b>
     </a></p>
     </a>
     <hr />
         

